SystemOrganization addCategory: #'GT-Playground'!

GLMCompositePresentation subclass: #GTPlayground
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Playground'!

GTPlayground class
	instanceVariableNames: 'repository'!

!GTPlayground commentStamp: 'TudorGirba 2/10/2014 11:31' prior: 0!
self open.
self reset.

Playground is the correspondent of a classic Smalltalk Workspace. The problem with the name Workspace is that it implies that work should be carried out in this space, while this is not a best practice. Playground describes better the intention of providing a place in which we can quickly play with some code.

self registerToolsOn: Smalltalk tools
!

GTPlayground class
	instanceVariableNames: 'repository'!

!GTPlayground class methodsFor: 'instance creation' stamp: 'TudorGirba 2/9/2014 00:36'!
open
	"self open"
	| page |
	page := GTPlaygroundPage new.
	^ self new openOn: page! !

!GTPlayground class methodsFor: 'instance creation' stamp: 'AndreiChis 4/21/2014 13:16'!
openContents: aString
	"Open a new playground with the given contents. aString has to be Smalltalk code. The style is applied"

	| page |
	page := GTPlaygroundPage new
		content: aString;
		yourself.
	^ self new openOn: page! !

!GTPlayground class methodsFor: 'instance creation' stamp: 'AndreiChis 4/21/2014 13:16'!
openContents: aString label: aLabel
	"Open a new playground with the given contents"

	| page |
	page := GTPlaygroundPage new
		content: aString;
		title: aLabel;
		yourself.
	^ self new openOn: page! !

!GTPlayground class methodsFor: 'tools registry' stamp: 'TudorGirba 2/9/2014 01:10'!
registerToolsOn: registry
	"Add ourselves to registry. See [Smalltalk tools]"
	"self registerToolsOn: Smalltalk tools" 
	registry register: self as: #workspace
! !

!GTPlayground class methodsFor: 'accessing' stamp: 'TudorGirba 2/8/2014 22:54'!
repository
	^ repository ifNil: [ repository := OrderedCollection new ]! !

!GTPlayground class methodsFor: 'accessing' stamp: 'TudorGirba 2/9/2014 00:37'!
reset
	repository := nil! !

!GTPlayground class methodsFor: 'tools registry' stamp: 'TudorGirba 2/11/2014 22:23'!
taskbarIcon
	"Answer the icon for the receiver in a task bar."

	^ Smalltalk ui icons iconNamed: #workspaceIcon! !

!GTPlayground methodsFor: 'building' stamp: 'TudorGirba 2/10/2014 06:38'!
actionsForPreviousContents
	^ self class repository reverse
		collect: [ :each | 
			GLMGenericAction new
				title: (each content asString contractTo: 50);
				action: [ :text | 
					self pushToRepositoryFrom: text.
					text entity: each.
					self class repository remove: each.
					text update ];
				yourself ]! !

!GTPlayground methodsFor: 'building' stamp: 'TudorGirba 5/30/2014 13:10'!
codeIn: a
	^ a pharoPlayground
		title: [ :page | page title ];
		format: [ :page | page content ];
		act: [ :text :page |
				page content: text text.
				text selectionInterval: (1 to: text text size).
				text evaluateSelectionAndDo: [ :result | text selection: result ]  ]
			icon: GLMUIThemeExtraIcons glamorousPlay
"			on: $O"
			entitled: 'Execute all and open';
		selectionAct: [ :text :page |
				page content: text text.
				text evaluateSelectionAndDo: [ :result | text selection: result ] ]
			on: $o
			entitled: 'Open';
		installDefaultSelectionActions;
		selectionAct: [ :text :page |
				text selectLine.
				self systemNavigation 
					browseMethodsWithString: text selectedText
					matchCase: false ]
			on: $E
			entitled: 'Extended string search';
		dynamicActions: [ self actionsForPreviousContents ]! !

!GTPlayground methodsFor: 'building' stamp: 'AndreiChis 8/21/2014 19:15'!
compose
	self
		title: 'Playground';
		custom:
			(GTInspector new
				noTitle; 
				noActions;
				showFirst: [ :composite |
					self codeIn: composite ];
				yourself);
		on: GLMBrowserClosing do: [ 
			"This is a hack for the moment.
			We need a better mechanism from Glamour to help 
			us keep the model in sync"
			self entity
					content: self first panes first presentations first text.
			self entity content asString trimBoth isEmpty
				ifFalse: [ self class repository add: self entity ] ]! !

!GTPlayground methodsFor: 'building' stamp: 'TudorGirba 2/9/2014 11:42'!
pushToRepositoryFrom: aTextPresentation
	| page |
	page := GTPlaygroundPage new.
	page content: aTextPresentation text.
	page content asString trimBoth isEmpty
		ifFalse: [ self class repository add: page ] ! !

Object subclass: #GTPlaygroundPage
	instanceVariableNames: 'title content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Playground'!

!GTPlaygroundPage commentStamp: 'TudorGirba 2/8/2014 22:59' prior: 0!
GTPlayground open!

!GTPlaygroundPage methodsFor: 'accessing' stamp: 'TudorGirba 2/3/2011 15:41'!
content
	^ content! !

!GTPlaygroundPage methodsFor: 'accessing' stamp: 'TudorGirba 2/3/2011 15:41'!
content: anObject
	content := anObject! !

!GTPlaygroundPage methodsFor: 'as yet unclassified' stamp: 'TudorGirba 4/22/2014 14:23'!
gtInspectorContentIn: composite
	<gtInspectorPresentationOrder: 40>
	composite pharoPlayground 
		title: 'Content';
		display: #content! !

!GTPlaygroundPage methodsFor: 'accessing' stamp: 'TudorGirba 2/8/2014 22:59'!
initialize
	content := ''.
	title := 'Playground'! !

!GTPlaygroundPage methodsFor: 'accessing' stamp: 'TudorGirba 2/3/2011 15:41'!
title
	^ title! !

!GTPlaygroundPage methodsFor: 'accessing' stamp: 'TudorGirba 2/3/2011 15:41'!
title: anObject
	title := anObject! !
